@@ -5,7 +5,6 @@ import Control.Monad.IO.Class
 import Data.List (intercalate)
 import GHC.Driver.Plugins
 import GHC.Plugins
-import GHC.Data.Bag
 import GHC.Tc.Types
 import Language.Haskell.Syntax.Extension
 import GHC.Hs.Expr
@@ -44,7 +43,7 @@ removeParsedBinding name (L l m)
 typecheckPlugin :: [CommandLineOption] -> ModSummary -> TcGblEnv -> TcM TcGblEnv
 typecheckPlugin [name, "typecheck"] _ tc
   = return $ tc { tcg_exports = filter (availNotNamedAs name) (tcg_exports tc)
-                , tcg_binds = filterBag (notNamedAs name) (tcg_binds tc)
+                , tcg_binds = filter (notNamedAs name) (tcg_binds tc)
                 }
   where notNamedAs name (L _ FunBind { fun_id = L _ fid })
           = occNameString (getOccName fid) /= name
@@ -54,9 +53,9 @@ typecheckPlugin [name, "typecheck"] _ tc
 typecheckPlugin _ _ tc = return tc
 
 metaPlugin' :: [CommandLineOption] -> LHsExpr GhcTc -> TcM (LHsExpr GhcTc)
-metaPlugin' [name, "meta"] (L l (XExpr (WrapExpr (HsWrap w (HsPar _ (L _ (HsApp noExt (L _ (HsVar _ (L _ id))) e)))))))
+metaPlugin' [name, "meta"] (L l (XExpr (WrapExpr w (HsPar _ (L _ (HsApp noExt (L _ (HsVar _ (L _ id))) e))))))
   | occNameString (getOccName id) == name
-  = return (L l (XExpr (WrapExpr (HsWrap w (unLoc e)))))
+  = return (L l (XExpr (WrapExpr w (unLoc e))))
 -- The test should always match this first case. If the desugaring changes
 -- again in the future then the panic is more useful than the previous
 -- inscrutable failure.
@@ -64,9 +63,10 @@ metaPlugin' _ meta = pprPanic "meta" (showAstData BlankSrcSpan BlankEpAnnotation
 
 interfaceLoadPlugin' :: [CommandLineOption] -> ModIface -> IfM lcl ModIface
 interfaceLoadPlugin' [name, "interface"] iface
-  = return $ iface { mi_exports = filter (availNotNamedAs name)
-                                         (mi_exports iface)
-                   }
+  = return $ set_mi_exports (filter (availNotNamedAs name)
+                                    (mi_exports iface))
+                            iface
+
 interfaceLoadPlugin' _ iface = return iface
 
 availNotNamedAs :: String -> AvailInfo -> Bool
